@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20141002';
+$VERSION = '5.20141020';
 
 sub utilities {
     my $perl = shift;
@@ -978,6 +978,13 @@ my %delta = (
         removed => {
         }
     },
+    5.021005 => {
+        delta_from => 5.021004,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
